import { ErrorWithStatus } from '@crosslab/service-common';
import { Mutex, withTimeout } from 'async-mutex';
export class MutexAcquisitionError extends ErrorWithStatus {
    constructor(message) {
        super(message, 409);
        this.name = 'MutexAcquisitionError';
    }
}
class MutexManager {
    timelimit = 3000;
    mutex = new Mutex();
    mutexMap = new Map();
    async acquire(id) {
        const release = await this.mutex.acquire();
        try {
            const mutex = this.mutexMap.get(id) ??
                withTimeout(new Mutex(), this.timelimit, new MutexAcquisitionError(`Timeout: Could not acquire the Mutex for "${id}" within the timelimit of ${this.timelimit}ms, please try again later`));
            if (!this.mutexMap.has(id))
                this.mutexMap.set(id, mutex);
            return await mutex.acquire();
        }
        finally {
            release();
        }
    }
}
export const mutexManager = new MutexManager();
//# sourceMappingURL=mutexManager.js.map